@@ -51,6 +51,8 @@ def lift_data(
     # Prepare the data for lifting: handle missing values in CHR, POS columns
     nrows = data.shape[0]
     data.dropna(subset=["CHR", "POS"], inplace=True)
+    # Remove absurd positions
+    data = data[data.POS < 300_000_000]
     data.reset_index(drop=True, inplace=True)
     n_na = nrows - data.shape[0]
     if n_na:
